@@ -10,6 +10,7 @@ Last Modified: January 12, 2021
 # built-in imports
 import contextlib
 import copy
+import itertools
 import json
 import pathlib
 import sys
@@ -256,6 +257,12 @@ class DatabaseManager:
             print(f"Creating output directory: {output}")
             output.mkdir(exist_ok=True)
 
+        preshared_keys = {}
+        for _combo_pair in itertools.combinations(peers, 2):
+            preshared_keys[
+                json.dumps(sorted(list(_combo_pair)))
+            ] = self.wireguard.genpsk()
+
         # for every peer in the database
         for peer in peers:
             with (output / f"{peer}.conf").open("w") as config:
@@ -286,6 +293,12 @@ class DatabaseManager:
                         )
                     )
 
+                    config.write(
+                        "PresharedKey = {}\n".format(
+                            preshared_keys[json.dumps(sorted(list({peer, p})))]
+                        )
+                    )
+
                     if database["peers"][p].get("Endpoint") is not None:
                         config.write(
                             "Endpoint = {}:{}\n".format(
